@@ -16,10 +16,10 @@
 
 #include "fdb5/LibFdb5.h"
 
-#include "eckit/eckit_version.h"
 #include "eckit/config/LibEcKit.h"
 #include "eckit/config/Resource.h"
 #include "eckit/config/YAMLConfiguration.h"
+#include "eckit/eckit_version.h"
 #include "eckit/exception/Exceptions.h"
 #include "eckit/log/Log.h"
 
@@ -40,16 +40,25 @@ LibFdb5& LibFdb5::instance() {
     return libfdb;
 }
 
-const Config& LibFdb5::defaultConfig() { 
-    if(!config_) {
+const Config& LibFdb5::defaultConfig(const eckit::Configuration& userConfig) {
+    if (!config_) {
         Config cfg;
-        config_.reset( new Config( std::move(cfg.expandConfig()) ) );
+        config_.reset(new Config(std::move(cfg.expandConfig()), userConfig));
     }
     return *config_;
 }
 
+ConstructorCallback LibFdb5::constructorCallback() {
+    return constructorCallback_;
+}
+
+void LibFdb5::registerConstructorCallback(ConstructorCallback cb) {
+    constructorCallback_ = cb;
+}
+
 bool LibFdb5::dontDeregisterFactories() const {
-#if eckit_VERSION_MAJOR > 1 || (eckit_VERSION_MAJOR == 1 && (eckit_VERSION_MINOR > 17 || (eckit_VERSION_MINOR == 17 && eckit_VERSION_PATCH >0)))
+#if eckit_VERSION_MAJOR > 1 || \
+    (eckit_VERSION_MAJOR == 1 && (eckit_VERSION_MINOR > 17 || (eckit_VERSION_MINOR == 17 && eckit_VERSION_PATCH > 0)))
     return eckit::LibEcKit::instance().dontDeregisterFactories();
 #else
     return false;
@@ -74,6 +83,11 @@ RemoteProtocolVersion LibFdb5::remoteProtocolVersion() const {
 }
 
 
+const std::set<std::string>& LibFdb5::auxiliaryRegistry() {
+    static std::set<std::string> auxiliaryRegistry(
+        eckit::Resource<std::set<std::string>>("$FDB_AUX_EXTENSIONS;fdbAuxExtensions", {"gribjump"}));
+    return auxiliaryRegistry;
+}
 //----------------------------------------------------------------------------------------------------------------------
 
 static unsigned getUserEnvRemoteProtocol() {
@@ -82,7 +96,7 @@ static unsigned getUserEnvRemoteProtocol() {
         eckit::Resource<unsigned>("fdbRemoteProtocolVersion;$FDB5_REMOTE_PROTOCOL_VERSION", 0);
     if (fdbRemoteProtocolVersion) {
         LOG_DEBUG_LIB(LibFdb5) << "fdbRemoteProtocolVersion overidde to version: " << fdbRemoteProtocolVersion
-                            << std::endl;
+                               << std::endl;
     }
     return 0;  // no version override
 }
@@ -92,10 +106,10 @@ static bool getUserEnvSkipSanityCheck() {
 }
 
 RemoteProtocolVersion::RemoteProtocolVersion() {
-    static unsigned  user = getUserEnvRemoteProtocol();
+    static unsigned user  = getUserEnvRemoteProtocol();
     static bool skipcheck = getUserEnvSkipSanityCheck();
 
-    if(not user) {
+    if (not user) {
         used_ = defaulted();
         return;
     }
