@@ -13,18 +13,16 @@
  * (Project ID: 671951) www.nextgenio.eu
  */
 
-#include "eckit/log/Log.h"
-#include "eckit/message/Message.h"
-#include "eckit/types/Types.h"
-#include "eckit/utils/Tokenizer.h"
-
-#include "fdb5/LibFdb5.h"
 #include "fdb5/api/SelectFDB.h"
+#include "eckit/log/Log.h"
+#include "fdb5/LibFdb5.h"
 #include "fdb5/api/helpers/FDBToolRequest.h"
 #include "fdb5/api/helpers/ListIterator.h"
-#include "fdb5/io/HandleGatherer.h"
+#include "fdb5/database/Key.h"
+#include "fdb5/rules/SelectMatcher.h"
 
 using namespace eckit;
+using namespace metkit::mars;
 
 namespace fdb5 {
 
@@ -32,39 +30,13 @@ static FDBBuilder<SelectFDB> selectFdbBuilder("select");
 
 //----------------------------------------------------------------------------------------------------------------------
 
-
-std::map<std::string, eckit::Regex> parseFDBSelect(const eckit::LocalConfiguration& config) {
-
-    std::map<std::string, eckit::Regex> selectDict;
-
-    // Select operates as constraints of the form: class=regex,key=regex,...
-    // By default, there is no select.
-
-    std::string select = config.getString("select", "");
-
-    std::vector<std::string> select_key_values;
-    eckit::Tokenizer(',')(select, select_key_values);
-
-    eckit::Tokenizer equalsTokenizer('=');
-    for (const std::string& key_value : select_key_values) {
-        std::vector<std::string> kv;
-        equalsTokenizer(key_value, kv);
-
-        if (kv.size() != 2 || selectDict.find(kv[0]) != selectDict.end()) {
-            std::stringstream ss;
-            ss << "Invalid select condition for pool: " << select << std::endl;
-            throw eckit::UserError(ss.str(), Here());
-        }
-
-        selectDict[kv[0]] = eckit::Regex(kv[1]);
-    }
-
-    return selectDict;
-}
-
 SelectFDB::FDBLane::FDBLane(const eckit::LocalConfiguration& config) :
-    select_(parseFDBSelect(config)), config_(config), fdb_(std::nullopt) {}
+    matcher_{config}, config_(config), fdb_(std::nullopt) {}
 
+template <typename T>  // T is either a MarsRequest or Key
+bool SelectFDB::FDBLane::matches(const T& vals, Matcher::MatchMissingPolicy matchOnMissing) const {
+    return matcher_.match(vals, matchOnMissing);
+}
 
 FDB& SelectFDB::FDBLane::get() {
     if (!fdb_) {
@@ -79,6 +51,8 @@ void SelectFDB::FDBLane::flush() {
     }
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 SelectFDB::SelectFDB(const Config& config, const std::string& name) : FDBBase(config, name) {
 
     ASSERT(config.getString("type", "") == "select");
@@ -105,7 +79,7 @@ SelectFDB::~SelectFDB() {}
 void SelectFDB::archive(const Key& key, const void* data, size_t length) {
 
     for (auto& lane : subFdbs_) {
-        if (matches(key, lane.select(), true)) {
+        if (lane.matches(key, Matcher::DontMatchOnMissing)) {
             lane.get().archive(key, data, length);
             return;
         }
@@ -116,13 +90,12 @@ void SelectFDB::archive(const Key& key, const void* data, size_t length) {
     throw eckit::UserError(ss.str(), Here());
 }
 
-ListIterator SelectFDB::inspect(const metkit::mars::MarsRequest& request) {
+ListIterator SelectFDB::inspect(const MarsRequest& request) {
 
     std::queue<APIIterator<ListElement>> lists;
 
     for (auto& lane : subFdbs_) {
-        // If we want to allow non-fully-specified retrieves, make false here.
-        if (matches(request, lane.select(), true)) {
+        if (lane.matches(request, Matcher::DontMatchOnMissing)) {
             lists.push(lane.get().inspect(request));
         }
     }
@@ -140,7 +113,7 @@ auto SelectFDB::queryInternal(const FDBToolRequest& request, const QueryFN& fn)
     std::queue<APIIterator<ValueType>> iterQueue;
 
     for (auto& lane : subFdbs_) {
-        if (request.all() || matches(request.request(), lane.select(), false)) {
+        if (request.all() || lane.matches(request.request(), Matcher::MatchOnMissing)) {
             iterQueue.push(fn(lane.get(), request));
         }
     }
@@ -209,51 +182,6 @@ void SelectFDB::print(std::ostream& s) const {
     s << "SelectFDB()";
 }
 
-bool SelectFDB::matches(const Key& key, const SelectMap& select, bool requireMissing) const {
-
-    for (const auto& [keyword, regex] : select) {
-        const auto [iter, found] = key.find(keyword);
-
-        if (!found) {
-            if (requireMissing) {
-                return false;
-            }
-        }
-        else {
-            if (!regex.match(iter->second)) {
-                return false;
-            }
-        }
-    }
-    return true;
-}
-
-bool SelectFDB::matches(const metkit::mars::MarsRequest& request, const SelectMap& select, bool requireMissing) const {
-
-    for (const auto& [keyword, regex] : select) {
-
-        const std::vector<std::string>& request_values = request.values(keyword, /* emptyOK */ true);
-
-        if (request_values.size() == 0) {
-            if (requireMissing)
-                return false;
-        }
-        else {
-            bool re_match = false;
-            for (const std::string& v : request_values) {
-                if (regex.match(v)) {
-                    re_match = true;
-                    break;
-                }
-            }
-            if (!re_match)
-                return false;
-        }
-    }
-
-    return true;
-}
-
 //----------------------------------------------------------------------------------------------------------------------
 
 }  // namespace fdb5
