@@ -31,30 +31,33 @@ class Archiver;
 
 class ArchiveVisitor : public BaseArchiveVisitor {
 
-public: // methods
+public:  // methods
 
-    ArchiveVisitor(Archiver& owner, const Key& dataKey, const void* data, size_t size, const ArchiveCallback& callback = CALLBACK_ARCHIVE_NOOP);
+    ArchiveVisitor(Archiver& owner, const Key& dataKey, const void* data, size_t size,
+                   const ArchiveCallback& callback = CALLBACK_ARCHIVE_NOOP);
+
+protected:  // methods
 
-protected: // methods
     bool selectDatum(const Key& datumKey, const Key& fullKey) override;
 
     void print(std::ostream& out) const override;
 
-private: // methods
+private:  // methods
 
-    void callbacks(fdb5::CatalogueWriter* catalogue, const Key& idxKey, const Key& datumKey, std::shared_ptr<std::promise<std::shared_ptr<const FieldLocation>>> p, std::shared_ptr<const FieldLocation> fieldLocation);
+    void callbacks(fdb5::CatalogueWriter* catalogue, const Key& idxKey, const Key& datumKey,
+                   std::shared_ptr<std::promise<std::shared_ptr<const FieldLocation>>> p,
+                   std::shared_ptr<const FieldLocation> fieldLocation);
 
-private: // members
+private:  // members
 
-    const void *data_;
+    const void* data_;
     size_t size_;
 
     const ArchiveCallback& callback_;
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
