@@ -14,8 +14,8 @@
 
 #pragma once
 
-#include "eckit/exception/Exceptions.h"
 #include "eckit/distributed/Transport.h"
+#include "eckit/exception/Exceptions.h"
 
 #include "metkit/mars/MarsRequest.h"
 
@@ -27,10 +27,9 @@ namespace fdb5 {
 
 class MoveVisitor : public EntryVisitor {
 
-public: // methods
+public:  // methods
 
-    MoveVisitor(const metkit::mars::MarsRequest& request,
-                const eckit::URI& dest);
+    MoveVisitor(const metkit::mars::MarsRequest& request, const eckit::URI& dest);
 
     ~MoveVisitor() override;
 
@@ -43,7 +42,7 @@ public: // methods
 
     void visitDatum(const Field& /*field*/, const std::string& /*keyFingerprint*/) override { NOTIMP; }
 
-protected: // members
+protected:  // members
 
     const metkit::mars::MarsRequest& request_;
     const eckit::URI& dest_;
@@ -51,4 +50,4 @@ protected: // members
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
