@@ -15,12 +15,10 @@ namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-Notifier::Notifier() {
-}
+Notifier::Notifier() {}
 
-Notifier::~Notifier() {
-}
+Notifier::~Notifier() {}
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
